@@ -42,14 +42,24 @@ class DictProxy(dict):
         return super(dict, self).__getattr__(name, default) 
 
 
-def Connector(url, username, password, list_id):
+def Connector(url, username, password, list_id, timeout=15):
     """ Sharepoint SOAP connector factory """
     transport = WindowsHttpAuthenticated(username=username,
                                          password=password,
-                                         timeout=50)
+                                         timeout=timeout)
     client = Client(url, transport=transport)
     client.set_options(service='Lists', port='ListsSoap12')
-    return ListEndpoint(client, list_id)
+
+    try:
+        return ListEndpoint(client, list_id)
+    except Exception, e:
+        # *try* to capture authentication related error.
+        # Suds fails dealing with a 403 response from Sharepoint in addition
+        # it is unable to deal with the error text returned from Sharepoint as
+        # *HTML*.
+        if '<unknown>' in str(e):
+            raise OperationalError('Unknown bug encountered - *possibly* an authentication problem (%s)' % e)
+        raise 
 
 
 class ParsedSoapResult(object):
@@ -62,6 +72,7 @@ class ParsedSoapResult(object):
     """
 
     def __init__(self, results):
+        self.raw_result = results
         self.ok = True
         self.result = list()
         # Stupid SOAP response are either returned as single 'Result'
@@ -94,6 +105,7 @@ class ListEndpoint(object):
         self.client = client
         self.service = client.service
         self.list_id = list_id
+        self.viewName = None
         # perform some introspection on the list
         self.model = self._getFields()       
         self.required_fields = self._required_fields()
@@ -153,9 +165,13 @@ class ListEndpoint(object):
             disallowed = ', '.join(list(data_keys - all_fields))
             raise ValueError('Data dictionary contains fieldnames unknown to the Sharepoint list model (Disallowed field names: %s)' % disallowed)
 
+    def setDefaultView(self, viewName):
+        """ set the default viewName parameter """
+        self.viewName = viewName
+
     def getItems(self, rowLimit=999999999, viewName=None):
         """ Return all list items without further filtering """
-        items = self.service.GetListItems(self.list_id, viewName=viewName, rowLimit=rowLimit)
+        items = self.service.GetListItems(self.list_id, viewName=viewName or self.viewName, rowLimit=rowLimit)
         return [self._serializeListItem(item) for item in items.listitems.data.row]
 
     def getItem(self, item_id, viewName=None):
@@ -175,7 +191,7 @@ class ListEndpoint(object):
         viewfields.append(Element('FieldRef').append(Attribute('Name', self.primary_key)))
         queryOptions = Element('queryOptions')
         result = self.service.GetListItems(self.list_id, 
-                                          viewName=viewName, 
+                                          viewName=viewName or self.viewName, 
                                           query=query0,  
                                           viewFields=viewfields, 
                                           queryOptions=queryOptions, 
@@ -216,19 +232,19 @@ class ListEndpoint(object):
         for k, v in kw.items():
             if not k in self.all_fields:
                 raise ValueError('List definition does not contain a field "%s"' % k)
-                
-            mode = Element(query_modes[mode])
-            where.append(mode)
+            
+            query_mode = Element(query_modes[mode])
+            where.append(query_mode)
             fieldref = Element('FieldRef').append(Attribute('Name', k))
             value = Element('Value').append(Attribute('Type', self.model[k]['Type'])).setText(v)
-            mode.append(fieldref)
-            mode.append(value)
+            query_mode.append(fieldref)
+            query_mode.append(value)
 
         viewfields = Element('ViewFields')
         viewfields.append(Element('FieldRef').append(Attribute('Name', self.primary_key)))
         queryOptions = Element('queryOptions')
         result = self.service.GetListItems(self.list_id, 
-                                          viewName=viewName, 
+                                          viewName=viewName or self.viewName, 
                                           query=query0,  
                                           viewFields=viewfields, 
                                           queryOptions=queryOptions, 
@@ -293,3 +309,10 @@ class ListEndpoint(object):
         result = self.service.UpdateListItems(self.list_id, updates)
         return ParsedSoapResult(result)
 
+    def checkout_file(self, pageUrl, checkoutToLocal=False):
+        """ Checkout a file """
+        return self.service.CheckOutFile(pageUrl, checkoutToLocal)
+
+    def checkin_file(self, pageUrl, comment=''):
+        return self.service.CheckInFile(pageUrl, comment)
+
